@@ -8,7 +8,7 @@
 /**
  * Abstract Visualization widget.
  */
-qx.Class.define("callbackery.ui.plugin.Table", {
+qx.Class.define('callbackery.ui.plugin.Table', {
     extend : callbackery.ui.plugin.Form,
     /**
      * create a page for the View Tab with the given title
@@ -65,16 +65,26 @@ qx.Class.define("callbackery.ui.plugin.Table", {
                 showCellFocusIndicator: false
             });
             var resizeBehavior = table.getTableColumnModel().getBehavior();
-            cfg.table.forEach(function(row,i){
-                if (row.width != null){
-                    resizeBehavior.setWidth(i, String(row.width));
+            cfg.table.forEach(function(col,i){
+                var tcm = table.getTableColumnModel();
+                if (col.type == 'date') {
+                    var cr =  new qx.ui.table.cellrenderer.Date;
+                    if (col.format != null) {
+                        cr.setDateFormat(new qx.util.format.DateFormat(col.format));
+                    }
+                    tcm.setDataCellRenderer(i, cr);
+                }
+                if (col.width != null){
+                    resizeBehavior.setWidth(i, String(col.width));
                 }
             });
             var selectionModel = table.getSelectionModel();
             selectionModel.setSelectionMode(qx.ui.table.selection.Model.SINGLE_SELECTION);
             selectionModel.addListener('changeSelection',function(){
                 selectionModel.iterateSelection(function(index) {
-                    this.setSelection(model.getRowData(index));
+                    if (model.getRowData(index) != null) {
+                        this.setSelection(model.getRowData(index));
+                    }
                 },this);
             },this);
             model.addListener('dataChanged',function(e){
@@ -94,14 +104,11 @@ qx.Class.define("callbackery.ui.plugin.Table", {
             },this);
             this._action.addListener('popupClosed',function(e){
                 model.reloadData();
-                selectionModel.setSelectionInterval(1,1);
             });
             this._action.addListener('actionResponse',function(e){
                 var data = e.getData();
                 switch (data.action){
                     case 'reload':
-                        model.reloadData();
-                        break;
                     case 'dataModified':
                         model.reloadData();
                         break;
